@@ -164,7 +164,9 @@ public:
 	{
 	public:
 		static bool isValue(const char *text);
+		static bool isText(const char *text);
 
+		static const char *chkPush(script *img, script::header *scr, script::line_t *line);
 		static const char *chkApply(script *img, script::header *scr, script::line_t *line);
 		static const char *chkIgnore(script *img, script::header *scr, script::line_t *line);
 		static const char *chkNop(script *img, script::header *scr, script::line_t *line);
@@ -389,6 +391,7 @@ public:
 	class __EXPORT methods : public script::interp
 	{
 	public:	
+		bool scrPush(void);
 		bool scrApply(void);
 		bool scrExpr(void);
 		bool scrVar(void);
@@ -468,6 +471,7 @@ public:
 	 */
 	static void init(void);
 
+	static unsigned offset(const char *list, unsigned index);
 	static void copy(const char *list, char *item, unsigned size);
 	static unsigned count(const char *list);
 	static const char *get(const char *list, unsigned offset);
