@@ -88,6 +88,16 @@ static unsigned getRequired(script::line_t *line)
 	return count;
 }
 
+bool script::checks::isText(const char *text)
+{
+	while(*text) {
+		if(!isalnum(*text))
+			return false;
+		++text;
+	}
+	return true;
+}
+
 bool script::checks::isValue(const char *text)
 {
 	switch(*text)
@@ -654,6 +664,41 @@ const char *script::checks::chkPack(script *img, script::header *scr, script::li
 	return NULL;
 }
 
+const char *script::checks::chkPush(script *img, script::header *scr, script::line_t *line)
+{
+	const char *cp;
+
+	if(line->argc < 1)
+		return "no symbol to push";
+
+	if(line->argc > 3)
+		return "only use value or key and value";
+
+	cp = line->argv[0];
+	switch(*cp) {
+	case '&':
+		return "cannot assign literal";
+	case '=':
+		return "no keywords are used in this command";
+	case '$':
+		return "cannot assign fielded symbols";
+	case '@':
+		return "cannot assign to label";
+	case '^':
+		return "cannot assign to event";
+	case '?':
+		return "cannot assign to expression";
+	}		
+	script::strict::createSym(img, scr, cp);
+	if(!isValue(line->argv[1]) && !isText(line->argv[1]))
+		return "cannot push from label or expression";
+
+	if(line->argv[2] && !isValue(line->argv[2]) && !isText(line->argv[1]))
+		return "cannot push value from label or expression";
+
+	return NULL;
+}
+
 const char *script::checks::chkSet(script *img, script::header *scr, script::line_t *line)
 {
 	unsigned drop = 0;
