@@ -330,6 +330,7 @@ void script::init(void)
 		{"const", (method_t)&methods::scrConst, (check_t)&checks::chkConst},
 		{"error", (method_t)&methods::scrError, (check_t)&checks::chkError},
 		{"clear", (method_t)&methods::scrClear, (check_t)&checks::chkClear},
+		{"push", (method_t)&methods::scrPush, (check_t)&checks::chkPush},
 		{"set", (method_t)&methods::scrSet, (check_t)&checks::chkSet},
 		{"add", (method_t)&methods::scrAdd, (check_t)&checks::chkSet},
 		{"pack", (method_t)&methods::scrPack, (check_t)&checks::chkPack},
@@ -1029,6 +1030,12 @@ void script::copy(const char *list, char *item, unsigned size)
 	*item = 0;
 }
 
+unsigned script::offset(const char *list, unsigned index)
+{
+	const char *cp = get(list, index);
+	return cp - list;
+}
+
 const char *script::get(const char *list, unsigned index)
 {
 	char quote = 0;
