@@ -123,6 +123,74 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 
 	if(String::equal(id, "len:", 4)) 
 		snprintf(tp, script::sizing + 1, "%u", (unsigned)strlen(sym->data));
+	else if(String::equal(id, "key:", 4)) {
+		String::set(tp, script::sizing + 1, sym->data);
+		ep = strchr(tp, '=');
+		if(ep)
+			*ep = 0; 
+		else
+			String::set(tp, 2, "-");
+	}
+	else if(String::equal(id, "tail:", 5)) {
+		dcount = script::count(sym->data);
+		if(dcount)
+			String::set(tp, script::sizing + 1, script::get(sym->data, --dcount));
+		else
+			tp[0] = 0;
+	}
+	else if(String::equal(id, "head:", 5)) {
+		String::set(tp, script::sizing + 1, sym->data);
+		if(script::count(tp) > 1) {
+			dcount = script::offset(tp, 1);
+			if(dcount)
+				tp[--dcount] = 0;
+		}
+	}
+	else if(String::equal(id, "pull:", 5)) {
+		String::set(tp, script::sizing + 1, sym->data);
+		if(script::count(tp) > 1) {
+			dcount = script::offset(tp, 1);
+			if(dcount) {
+				memcpy(sym->data, sym->data + dcount, strlen(sym->data + dcount) + 1);
+				tp[--dcount] = 0;
+			}
+		}
+	}
+	else if(String::equal(id, "pop:", 4)) {
+		dcount = script::count(sym->data);
+		if(dcount) {
+			String::set(tp, script::sizing + 1, script::get(sym->data, --dcount));
+			if(dcount) {
+				dcount = script::offset(sym->data, dcount);
+				sym->data[--dcount] = 0;
+			}
+			else
+				sym->data[0] = 0;
+		}
+		else
+			tp[0] = 0;
+	}		
+	else if(String::equal(id, "val:", 4) && (sym->data[0] == '\'' || sym->data[0] == '\"')) {
+		String::set(tp, script::sizing + 1, sym->data + 1);
+		ep = strchr(tp, sym->data[0]);
+		if(ep)
+			*ep = 0;
+	}
+	else if(String::equal(id, "val:", 4) && strchr(sym->data, '=')) {
+		cp = strchr(sym->data, '=') + 1;
+		if(*cp == '\"' || *cp == '\'') {
+			String::set(tp, script::sizing + 1, cp + 1);
+			ep = strchr(tp, *cp);
+			if(ep)
+				*ep = 0;
+		}
+		else {
+			String::set(tp, script::sizing + 1, cp);
+			ep = strchr(tp, ',');
+			if(ep)
+				*ep = 0;
+		}
+	}  
 	else if(String::equal(id, "inc:", 4) && sym->size) {
 		val = atol(sym->data);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, ++val);
@@ -130,6 +198,28 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	}
 	else if(String::equal(id, "count:", 6))
 		snprintf(tp, script::sizing + 1, "%u", script::count(sym->data)); 
+	else if(String::equal(id, "index/", 6)) {
+		id += 6;
+		pos = atoi(id);
+		if(pos)
+			--pos;
+		else {
+			snprintf(tp, script::sizing + 1, "%s", id);
+			ep = strchr(tp, ':');
+			*ep = 0;
+			index = find(tp);
+			if(!index)
+				return "";
+			pos = atoi(index->data);
+			if(pos)
+				--pos;
+		}
+		if(pos < strlen(sym->data))
+			cp = sym->data + pos;
+		else
+			cp = "";
+		script::copy(cp, tp, script::sizing);
+	}
 	else if(String::equal(id, "offset/", 7)) {
 		id += 7;
 		pos = atoi(id);
